@@ -1289,6 +1289,10 @@ def parse():
     parser.add_argument(
         '-f', '--force', action='store_true', default=False,
         dest = 'no_questions', help=_('silent during the process'))
+    parser.add_argument(
+        '-P', action='store_true', default=False,
+        dest = 'stdin_passwd',
+        help=_('use passwords for the users accounts from standard input'))
     parser.add_argument(
         '--variable', type=str, dest='variable', 
         help=_("display the value for the specified variable "
